yetibot.api.catchpoint

Catch point API interface. See Catchpoint docs at: https://io.catchpoint.com/ui/help

Catch point API interface. See Catchpoint docs at:
https://io.catchpoint.com/ui/help
raw docstring

api-uriclj

(api-uri endpoint)
source

configclj

(config)
source

fetchclj

(fetch endpoint)
(fetch endpoint {:keys [query-params]})
source

fetch-tokenclj

(fetch-token)
source

format-test-dataclj

(format-test-data {start-date :start
                   {status :name} :status
                   description :description
                   :as test-data
                   test-url :test_url
                   change-date :change_date
                   {simulate :name} :simulate
                   {test-type :name} :test_type
                   test-name :name})
source

headersclj

(headers)
source

hostclj

source

metric-by-index-or-patternclj

(metric-by-index-or-pattern metric-index-or-pattern metrics)
source

prefixclj

source

raw-performanceclj

(raw-performance test-id)
source

raw-performance-for-matched-testclj

(raw-performance-for-matched-test id-or-test-match)
source

refresh-interval-msclj

source

refresh-loopclj

source

refresh-token!clj

(refresh-token!)
source

resolve-test-idclj

(resolve-test-id id-or-test-match)
source

resolve-testsclj

(resolve-tests test-to-match)

Given a string, match it against known tests and retrieve test ID for the first match

Given a string, match it against known tests and retrieve test ID for the
first match
sourceraw docstring

test-by-idclj

(test-by-id id)
source

testsclj

(tests)
source

tokenclj

source

token-uriclj

(token-uri)
source

versionclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries