yetibot.api.jira

Interface with a configured JIRA instance. Note: there are slight differences between server instances and JIRA Cloud, so some features may not be fully compatible. In most cases these functions were developed against a JIRA Enterprise instance.

To view all versions of the JIRA Rest API (and to suddelyl feel like you're living in the 90s), visit: https://docs.atlassian.com/software/jira/docs/api/REST/

This listing doesn't seem up to date as https://docs.atlassian.com/software/jira/docs/api/REST/8.5.3/ exists but is not in the listing.

Safest choice might be to develop against latest of Server REST API: https://docs.atlassian.com/software/jira/docs/api/REST/latest/

Hopefully someday they unify the cloud and enterprise APIs.

Interface with a configured JIRA instance. Note: there are slight differences
between server instances and JIRA Cloud, so some features may not be fully
compatible. In most cases these functions were developed against a JIRA
Enterprise instance.

To view all versions of the JIRA Rest API (and to suddelyl feel like you're
living in the 90s), visit:
https://docs.atlassian.com/software/jira/docs/api/REST/

This listing doesn't seem up to date  as
https://docs.atlassian.com/software/jira/docs/api/REST/8.5.3/
exists but is not in the listing.

Safest choice might be to develop against `latest` of Server REST API:
https://docs.atlassian.com/software/jira/docs/api/REST/latest/

Hopefully someday they unify the cloud and enterprise APIs.
raw docstring

*jira-project*clj

Settings for the current channel, bound by yetibot.commands.jira

Settings for the current channel, bound by yetibot.commands.jira
sourceraw docstring

*jira-projects*clj

Settings for the current channel, bound by yetibot.commands.jira

Settings for the current channel, bound by yetibot.commands.jira
sourceraw docstring

access-token-urlclj

source

add-worklog-itemclj

(add-worklog-item issue-key time-spent work-description)
source

all-componentsclj

source

api-uriclj

(api-uri)
source

authclj

source

authorize-urlclj

source

base-uriclj

(base-uri)
source

channel-projectsclj

(channel-projects channel-settings)

Retrieve the list of configured projects for a channel, given its settings

Retrieve the list of configured projects for a channel, given its settings
sourceraw docstring

client-optsclj

(client-opts uri http-method & [query-params])

For oauth1 client-opts need to be computed for every API in order to generate an authz header, baking any query-params into the signature.

http-method should be: :GET :POST :PUT or :DELETE

For oauth1 client-opts need to be computed for every API in order to generate
an authz header, baking any query-params into the signature.

http-method should be: :GET :POST :PUT or :DELETE
sourceraw docstring

cloud?clj

(cloud?)
Whether or not to use Cloud REST API calls:
https://developer.atlassian.com/cloud/jira/platform/rest/v2/#api-group-User-search
sourceraw docstring

componentsclj

(components project-key)
source

configclj

(config)
source

configured?clj

(configured?)
source

consumerclj

source

create-issueclj

(create-issue
  {:keys [summary component-ids reporter assignee priority-key desc project-key
          fix-version timetracking issue-type-id parent]
   :or {desc ""
        assignee "-1"
        issue-type-id
          (if parent (sub-task-issue-type-id) (default-issue-type-id))
        project-key (or (first *jira-projects*) (default-project-key))}})

This thing is a beast; thanks JIRA.

This thing is a beast; thanks JIRA.
sourceraw docstring

date-time-formatclj

source

default-issue-type-idclj

(default-issue-type-id)
source

default-projectclj

(default-project)
source

default-project-keyclj

(default-project-key)
source

default-version-idclj

(default-version-id project-key)
source

delete-issueclj

(delete-issue issue-key)
source

endpointclj

(endpoint & fmt-with-args)
source

fetch-and-format-issue-shortclj

source

find-component-likeclj

(find-component-like pattern-str)

Match components across all projects

Match components across all projects
sourceraw docstring

find-priority-by-keyclj

(find-priority-by-key k)
source

find-projectclj

(find-project pk)
source

find-transitionclj

(find-transition issue-key query)

Use regex to find by partial match on transition name

Use regex to find by partial match on transition name
sourceraw docstring

format-attachment-itemclj

(format-attachment-item a)
source

format-attachmentsclj

(format-attachments issue-data)
source

format-commentclj

(format-comment c)
source

format-issueclj

(format-issue issue-data)
source

format-issue-longclj

(format-issue-long issue-data)

Show the full details for an issue

Show the full details for an issue
sourceraw docstring

format-issue-shortclj

(format-issue-short issue-data)
source

format-projectclj

(format-project {{project-category-name :name} :projectCategory
                 project-key :key
                 project-name :name
                 :as project})
source

format-subtasksclj

(format-subtasks {{subtasks :subtasks} :fields})
source

format-worklog-itemclj

(format-worklog-item w)
source

format-worklog-itemsclj

(format-worklog-items issue-data)
source

get-issueclj

(get-issue i)

Fetch json for a given JIRA

Fetch json for a given JIRA
sourceraw docstring

get-projectsclj

(get-projects & [query])
source

get-transitionsclj

(get-transitions i)
source

get-usersclj

(get-users project)
source

http-deleteclj

(http-delete uri & [{:keys [query-params] :as opts}])
source

http-getclj

(http-get uri & [{:keys [query-params] :as opts}])
source

http-postclj

(http-post uri & [{:keys [query-params] :as opts}])
source

http-putclj

(http-put uri & [{:keys [query-params] :as opts}])
source

issue-create-metaclj

(issue-create-meta)
source

issue-typesclj

(issue-types)
source

jira-project-setting-keyclj

This key is used to store channel-specific JIRA projects

This key is used to store channel-specific JIRA projects
sourceraw docstring

max-resultsclj

(max-results)
source

oauth1clj

source

parse-and-format-date-stringclj

(parse-and-format-date-string date-string)
source

post-commentclj

(post-comment issue-key body)
source

prioritiesclj

(priorities)
source

project-for-keyclj

(project-for-key k)
source

project-keysclj

(project-keys)
source

project-keys-strclj

(project-keys-str)
source

projectsclj

(projects)
source

recentclj

(recent & [project])
source

request-token-urlclj

source

resolve-issueclj

(resolve-issue i comment)

Transition an issue to the resolved state. If it is unable to make that transition nil will be returned

Transition an issue to the resolved state. If it is unable to make that
transition nil will be returned
sourceraw docstring

resolve-user-by-queryclj

(resolve-user-by-query user-query)

Given a query representing a user return the first match, if any

Given a query representing a user return the first match, if any
sourceraw docstring

(search jql)
source

search-by-queryclj

(search-by-query query)
source

search-in-projectsclj

(search-in-projects jql)
source

search-usersclj

(search-users query)

Find a user entity matching against display name and email.

query - A query string that is matched against user attributes ( displayName, and emailAddress) to find relevant users. The string can match the prefix of the attribute's value. For example, query=john matches a user with a displayName of John Smith and a user with an emailAddress of johnson@example.com

Find a user entity matching against display name and email.

query - A query string that is matched against user attributes ( displayName,
and emailAddress) to find relevant users. The string can match the prefix of
the attribute's value. For example, query=john matches a user with a
displayName of John Smith and a user with an emailAddress of
johnson@example.com
sourceraw docstring

sub-task-issue-type-idclj

(sub-task-issue-type-id)
source

transition-issueclj

(transition-issue i transition-id & iss-comment)
source

update-issueclj

(update-issue issue-key
              {:keys [fix-version summary component-ids reporter assignee
                      priority-key desc timetracking]})
source

url-from-keyclj

(url-from-key k)
source

user-refclj

(user-ref assignee-user)

Jira Cloud and Server take different params when referencing users. Abstract the diff with this function

Jira Cloud and Server take different params when referencing users. Abstract
the diff with this function
sourceraw docstring

versionsclj

(versions)
(versions project-key)
source

cljdoc builds & hosts documentation for Clojure/Script libraries