yetibot.commands.emoji-kitchen


emoji-kitchenclj

(emoji-kitchen {[_ arg1 arg2] :match chat-source :chat-source :as cmd-args})

ek <emoji-1> <emoji-2> # fetch an emoji from emoji kitchen

ek <emoji-1> <emoji-2> # fetch an emoji from emoji kitchen
sourceraw docstring

extract-slack-emojiclj

(extract-slack-emoji {:keys [blocks] :as raw-event})

Given a slack event, extract the unicode emoji

Given a slack event, extract the unicode emoji
sourceraw docstring

fetch-emojiclj

(fetch-emoji emoji-1 emoji-2)

Fetch an emoji from emoji kitchen given two unicode emoji

Fetch an emoji from emoji kitchen given two unicode emoji
sourceraw docstring

hex-to-unicharclj

(hex-to-unichar hex)

Convert a hex string to a unicode character

Convert a hex string to a unicode character
sourceraw docstring

urlclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries