(lookup-features _)features # look up Yetibot's current list of feature requests
features # look up Yetibot's current list of feature requests
(request-feature-cmd {[_ body] :match})features request <text> # request a feature
features request <text> # request a feature
(should-add-feature? body)Loop the regexes that think we should add a feature
Loop the regexes that think we should add a feature
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |