yetibot.commands.google


built-cli-optionsclj

source

cli-argsclj

source

command-not-foundclj

(command-not-found _)
source

common-messaging-interfaceclj

(common-messaging-interface status
                            message
                            &
                            {:keys [results] :or {results nil}})
source

common-search-functionclj

(common-search-function query
                        &
                        {:keys [sfunction type]
                         :or {sfunction api/search type :normal}})
source

convert-keys-into-google-keywordsclj

(convert-keys-into-google-keywords obj)
source

copy-of-valid-file-optionsclj

source

fetch-option-if-existsclj

(fetch-option-if-exists option)
source

get-infoclj

(get-info option)

Gets info about an option. Also includes valid input info

Gets info about an option.
Also includes valid input info
sourceraw docstring

get-option-cli-infoclj

(get-option-cli-info option)
source

(image-search {[_ query] :match})

google image <query> # image search

google image <query> # image search
sourceraw docstring

keyword->apikeywordclj

(keyword->apikeyword option)
source

load-options-from-file-into-atomclj

(load-options-from-file-into-atom)
source

messagesclj

source

option-infoclj

(option-info {[_ query] :match})

google option-info <query> #display info for option

google option-info <query> #display info for option
sourceraw docstring

optionsclj

(options _)

google options # show list of valid options

google options # show list of valid options
sourceraw docstring

options-atomclj

source

options-processorclj

(options-processor string)
source

render-option-infoclj

(render-option-info option info)
source

reset-optionsclj

(reset-options _)

google reset options # current set options are vanquished

google reset options # current set options are vanquished
sourceraw docstring

restore-optionsclj

(restore-options _)

google restore options # restore from file config

google restore options # restore from file config
sourceraw docstring

(search {[_ query] :match})

google search <query> # plain google search

google search <query> # plain google search
sourceraw docstring

search-function-input-validationclj

(search-function-input-validation query)
source

set-optionclj

(set-option {[_ option value] :match})

google set <option> <value>

google set <option> <value>
sourceraw docstring

set-option-valueclj

(set-option-value option value)

This is responsible for checking if a key exists. If it does, it validates the value given.

This is responsible for checking if a key exists.
If it does, it validates the value given.
sourceraw docstring

show-set-optionsclj

(show-set-options _)

google show set options

google show set options
sourceraw docstring

state-of-set-optionsclj

(state-of-set-options)
source

valid-keywords-listclj

source

validate-option-valueclj

(validate-option-value option value)
source

cljdoc builds & hosts documentation for Clojure/Script libraries