yetibot.commands.notit


candidate-itsclj

source

do-resetclj

(do-reset)
source

get-not-itsclj

(get-not-its)
source

not-itsclj

source

register-not-itclj

(register-not-it {:keys [user]})

notit # register a user as not-it

notit # register a user as not-it
sourceraw docstring

reset-itsclj

(reset-its _)

notit reset # resets the current not-it list

notit reset # resets the current not-it list
sourceraw docstring

show-itsclj

(show-its _)

notit show # show the current list of users registered as not-it

notit show # show the current list of users registered as not-it
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries