yetibot.commands.pirate


dictclj

source

flavorclj

source

get-varclj

(get-var resource-file)
source

if-probclj

(if-prob s f prob)

Optionally apply fn f to string s, based on probability prob.

Optionally apply fn f to string s, based on probability prob.
sourceraw docstring

local-tzclj

source

pirate-cmdclj

(pirate-cmd {s :match})

pirate <string> # translate string into proper pirate, yar

pirate <string> # translate string into proper pirate, yar
sourceraw docstring

probabilityclj

(probability)

Return probability, by hour, for configured TZ.

Return probability, by hour, for configured TZ.
sourceraw docstring

slur-reclj

source

slurrrclj

(slurrr s)

I'm not drunk, you're drunk.

I'm not drunk, you're drunk.
sourceraw docstring

sub-wordclj

(sub-word s)
source

suffix-flavorclj

(suffix-flavor s)

Suffix random pirate flavor.

Suffix random pirate flavor.
sourceraw docstring

to-pirateclj

(to-pirate s)
source

wrap-capitalizationclj

(wrap-capitalization f)

Expects a fn, f, and returns a fn taking one arg: a string. We upper-case the first char of the return of the wrapped fn, f, if the string had an initial upper-case char.

Expects a fn, f, and returns a fn taking one arg: a string.  We
upper-case the first char of the return of the wrapped fn, f, if the
string had an initial upper-case char.
sourceraw docstring

wrap-punctuationclj

(wrap-punctuation f)

Expects a fn, f, and returns a fn taking one arg: a string. We strip trailing punctuation before calling the wrapped fn f, replacing on the return of f.

Expects a fn, f, and returns a fn taking one arg: a string.  We strip
trailing punctuation before calling the wrapped fn f, replacing on
the return of f.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries