yetibot.commands.tldr


all-platformsclj

source

commands-uriclj

source

fetch-commandsclj

(fetch-commands)

Returns a list of all the tldr commands available

Returns a list of all the tldr commands available
sourceraw docstring

one-hour-msecsclj

source

page-uriclj

source

tldrclj

(tldr command)
(tldr platforms command)

Returns TLDR page markdown for a command.

Returns TLDR page markdown for a `command`.
sourceraw docstring

tldr-cmdclj

(tldr-cmd {[_ command] :match})

tldr <command> # get typical usages of a command

tldr <command> # get typical usages of a command
sourceraw docstring

tldr-commandsclj

source

tldr-platform-cmdclj

(tldr-platform-cmd {[_ platform command] :match})

tldr <platform>/<command> # get typical usages of a command for a platform

tldr <platform>/<command> # get typical usages of a command for a platform
sourceraw docstring

tldr-randomclj

(tldr-random _)

Returns a random tldr command

Returns a random tldr command
sourceraw docstring

(tldr-search query)

Returns a string of all the tldr commands whose names contain <query>

Returns a string of all the tldr commands whose names contain <query>
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries