yetibot.commands.twitter


displayclj

(display {[_ id] :match})

twitter display <id> # display tweet with <id>

twitter display <id> # display tweet with <id>
sourceraw docstring

followclj

(follow {[_ screen-name] :match})

twitter follow <screen-name> # follow a Twitter user

twitter follow <screen-name> # follow a Twitter user
sourceraw docstring

followingclj

(following _)

twitter following # list Twitter users you are following

twitter following # list Twitter users you are following
sourceraw docstring

limit-charsclj

source

lookupclj

(lookup {[_ screen-name] :match})

twitter lookup <screen-name> # look up info on Twitter user

twitter lookup <screen-name> # look up info on Twitter user
sourceraw docstring

replyclj

(reply {[_ id status] :match})

twitter reply <id> <status> # note that the author's username of the referenced tweet must be mentioned

twitter reply <id> <status> # note that the author's username of the referenced tweet must be mentioned
sourceraw docstring

retweetclj

(retweet {[_ id] :match})

twitter retweet <id>

twitter retweet <id>
sourceraw docstring

(search {[_ query] :match})

twitter search <query> # find most recent 20 tweets matching <query>

twitter search <query> # find most recent 20 tweets matching <query>
sourceraw docstring

showclj

(show {[_ screen-name] :match})

twitter show <screen-name> # show top 10 tweets from user <scree-name>

twitter show <screen-name> # show top 10 tweets from user <scree-name>
sourceraw docstring

trackclj

(track {[_ topic] :match user :user})

twitter track <topic> # track a <topic> on the Twitter stream

twitter track <topic> # track a <topic> on the Twitter stream
sourceraw docstring

trackingclj

(tracking _)

twitter tracking # show the topics that are being tracked on Twitter

twitter tracking # show the topics that are being tracked on Twitter
sourceraw docstring

tweetclj

(tweet {[_ status] :match})

twitter tweet <status> # post <status> to Twitter

twitter tweet <status> # post <status> to Twitter
sourceraw docstring

unfollowclj

(unfollow {[_ screen-name] :match})

twitter unfollow <screen-name> # stop following a Twitter user

twitter unfollow <screen-name> # stop following a Twitter user
sourceraw docstring

untrackclj

(untrack {[_ topic] :match})

twitter untrack <topic> # stop tracking <topic>

twitter untrack <topic> # stop tracking <topic>
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries