yetibot.commands.weather


airclj

(air loc)
source

air-cmdclj

(air-cmd {[_ loc] :match})

weather air <location> # look up current air conditions for <location> by name or postal code, optional country code

weather air <location> # look up current air conditions for <location> by name or postal code, optional country code
sourceraw docstring

api-keyclj

source

configclj

source

currentclj

(current loc)
source

default-air-cmdclj

(default-air-cmd _)

weather air # look up current weather for default location

weather air # look up current weather for default location
sourceraw docstring

default-weather-cmdclj

(default-weather-cmd _)

weather # look up weather for default location

weather # look up weather for default location
sourceraw docstring

default-zipclj

source

forecastclj

(forecast loc)
source

forecast-cmdclj

(forecast-cmd {[_ match] :match})

weather forecast <location> # look up forecast for <location> by name or postal code, optional country code, -c or -f to force units

weather forecast <location> # look up forecast for <location> by name or postal code, optional country code, -c or -f to force units
sourceraw docstring

get-jsonclj

(get-json uri {:keys [query-params] :as opts})
source

parse-argsclj

(parse-args s)

parse args to vec of unit kw and args str

parse args to vec of unit kw and args str
sourceraw docstring

weather-cmdclj

(weather-cmd {:keys [match]})

weather <location> # look up current weather for <location> by name or postal code, optional country code, -c or -f to force units

weather <location> # look up current weather for <location> by name or postal code, optional country code, -c or -f to force units
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries