yetibot.commands.wordnik


configclj

source

defineclj

(define {[_ w] :match})

wordnik define <word> # look up the definition for <word> on Wordnik

wordnik define <word> # look up the definition for <word> on Wordnik
sourceraw docstring

randomclj

(random _)

wordnik random # look up a random word on Wordnik

wordnik random # look up a random word on Wordnik
sourceraw docstring

wotdclj

(wotd _)

wordnik wotd # look up the Word of the Day on Wordnik

wordnik wotd # look up the Word of the Day on Wordnik
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries