yetibot.models.postal-code


chk-postal-codeclj

(chk-postal-code s)
(chk-postal-code s cc)

Check postal codes, optionally qualified by CC. Returns a vector of ISO country code and the canonical format of the postal code.

Check postal codes, optionally qualified by CC.  Returns a vector of
ISO country code and the canonical format of the postal code.
sourceraw docstring

find-postal-codeclj

(find-postal-code s postal-codes)
source

gb-cleanupclj

(gb-cleanup a b c d)
source

postal-codesclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries