yetibot.util


oauth1-credentialsclj

(oauth1-credentials consumer
                    token
                    verifier
                    request-method
                    request-uri
                    &
                    [request-params])

Return authorization credentials needed for access to protected resources. The key-value pairs returned as a map will need to be added to the Authorization HTTP header or added as query parameters to the request.

Modified from https://github.com/mattrepl/clj-oauth/blob/master/src/oauth/client.clj

Return authorization credentials needed for access to protected resources.
The key-value pairs returned as a map will need to be added to the
Authorization HTTP header or added as query parameters to the request.

Modified from https://github.com/mattrepl/clj-oauth/blob/master/src/oauth/client.clj
sourceraw docstring

rsa-signclj

(rsa-sign data-to-sign priv-key)
source

cljdoc builds & hosts documentation for Clojure/Script libraries