Interface with a configured JIRA instance. Note: there are slight differences between server instances and JIRA Cloud, so some features may not be fully compatible. In most cases these functions were developed against a JIRA Enterprise instance.
To view all versions of the JIRA Rest API (and to suddelyl feel like you're living in the 90s), visit: https://docs.atlassian.com/software/jira/docs/api/REST/
This listing doesn't seem up to date as https://docs.atlassian.com/software/jira/docs/api/REST/8.5.3/ exists but is not in the listing.
Safest choice might be to develop against latest of Server REST API:
https://docs.atlassian.com/software/jira/docs/api/REST/latest/
Hopefully someday they unify the cloud and enterprise APIs.
Interface with a configured JIRA instance. Note: there are slight differences between server instances and JIRA Cloud, so some features may not be fully compatible. In most cases these functions were developed against a JIRA Enterprise instance. To view all versions of the JIRA Rest API (and to suddelyl feel like you're living in the 90s), visit: https://docs.atlassian.com/software/jira/docs/api/REST/ This listing doesn't seem up to date as https://docs.atlassian.com/software/jira/docs/api/REST/8.5.3/ exists but is not in the listing. Safest choice might be to develop against `latest` of Server REST API: https://docs.atlassian.com/software/jira/docs/api/REST/latest/ Hopefully someday they unify the cloud and enterprise APIs.
Settings for the current channel, bound by yetibot.commands.jira
Settings for the current channel, bound by yetibot.commands.jira
Settings for the current channel, bound by yetibot.commands.jira
Settings for the current channel, bound by yetibot.commands.jira
(channel-projects channel-settings)Retrieve the list of configured projects for a channel, given its settings
Retrieve the list of configured projects for a channel, given its settings
(client-opts uri http-method & [query-params])For oauth1 client-opts need to be computed for every API in order to generate an authz header, baking any query-params into the signature.
http-method should be: :GET :POST :PUT or :DELETE
For oauth1 client-opts need to be computed for every API in order to generate an authz header, baking any query-params into the signature. http-method should be: :GET :POST :PUT or :DELETE
(cloud?)Whether or not to use Cloud REST API calls: https://developer.atlassian.com/cloud/jira/platform/rest/v2/#api-group-User-search
Whether or not to use Cloud REST API calls: https://developer.atlassian.com/cloud/jira/platform/rest/v2/#api-group-User-search
(create-issue
{:keys [summary component-ids reporter assignee priority-key desc project-key
fix-version timetracking issue-type-id parent]
:or {desc ""
assignee "-1"
issue-type-id
(if parent (sub-task-issue-type-id) (default-issue-type-id))
project-key (or (first *jira-projects*) (default-project-key))}})This thing is a beast; thanks JIRA.
This thing is a beast; thanks JIRA.
(find-component-like pattern-str)Match components across all projects
Match components across all projects
(find-transition issue-key query)Use regex to find by partial match on transition name
Use regex to find by partial match on transition name
(format-issue-long issue-data)Show the full details for an issue
Show the full details for an issue
(format-project {{project-category-name :name} :projectCategory
project-key :key
project-name :name
:as project})(get-issue i)Fetch json for a given JIRA
Fetch json for a given JIRA
This key is used to store channel-specific JIRA projects
This key is used to store channel-specific JIRA projects
(resolve-issue i comment)Transition an issue to the resolved state. If it is unable to make that transition nil will be returned
Transition an issue to the resolved state. If it is unable to make that transition nil will be returned
(resolve-user-by-query user-query)Given a query representing a user return the first match, if any
Given a query representing a user return the first match, if any
(search-users query)Find a user entity matching against display name and email.
query - A query string that is matched against user attributes ( displayName, and emailAddress) to find relevant users. The string can match the prefix of the attribute's value. For example, query=john matches a user with a displayName of John Smith and a user with an emailAddress of johnson@example.com
Find a user entity matching against display name and email. query - A query string that is matched against user attributes ( displayName, and emailAddress) to find relevant users. The string can match the prefix of the attribute's value. For example, query=john matches a user with a displayName of John Smith and a user with an emailAddress of johnson@example.com
(update-issue issue-key
{:keys [fix-version summary component-ids reporter assignee
priority-key desc timetracking]})(user-ref assignee-user)Jira Cloud and Server take different params when referencing users. Abstract the diff with this function
Jira Cloud and Server take different params when referencing users. Abstract the diff with this function
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |