(iam-add-user-to-group-cmd {[_ group-name user-name] :match})aws iam add-user-to-group <group-name> <user-name> # Adds an aws IAM user <user-name> to an IAM group <group-name>
aws iam add-user-to-group <group-name> <user-name> # Adds an aws IAM user <user-name> to an IAM group <group-name>
(iam-attach-user-policy-cmd {[_ user-name policy-arn] :match})aws iam attach-user-policy <user-name> <arn> # Attaches the specified managed policy whose Arn is <arn> to the specified user.
aws iam attach-user-policy <user-name> <arn> # Attaches the specified managed policy whose Arn is <arn> to the specified user.
(iam-create-access-key-cmd {[_ user-name] :match})aws iam create-access-key <user-name> # Creates a new AWS secret access key and corresponding AWS access key ID for the specified user
aws iam create-access-key <user-name> # Creates a new AWS secret access key and corresponding AWS access key ID for the specified user
(iam-create-group-cmd {[_ group-name] :match})aws iam create-group <group-name> # Creates an aws IAM group named <group-name> within the default path /
aws iam create-group <group-name> # Creates an aws IAM group named <group-name> within the default path /
(iam-create-group-in-path-cmd {[_ path group-name] :match})aws iam create-group <path> <group-name> # Creates an aws IAM group named <group-name> within the specified <path>
aws iam create-group <path> <group-name> # Creates an aws IAM group named <group-name> within the specified <path>
(iam-create-login-profile-cmd {[_ user-name password] :match})aws iam create-login-profile <user-name> <password> # Creates a temporary password for the specified user, giving the user the ability to access AWS services through the AWS Management Console and change it the first time they connect.
aws iam create-login-profile <user-name> <password> # Creates a temporary password for the specified user, giving the user the ability to access AWS services through the AWS Management Console and change it the first time they connect.
(iam-create-user-cmd {[_ user-name] :match})aws iam create-user <user-name> # Creates an aws IAM user named <user-name>
aws iam create-user <user-name> # Creates an aws IAM user named <user-name>
(iam-create-user-in-path-cmd {[_ path user-name] :match})aws iam create-user <path> <user-name> # Creates an aws IAM user named <user-name> within the specified <path> prefix
aws iam create-user <path> <user-name> # Creates an aws IAM user named <user-name> within the specified <path> prefix
(iam-delete-access-key-cmd {[_ user-name access-key-id] :match})aws iam delete-access-key <user-name> <access-key-id> # Deletes the access key pair associated with the specified IAM user
aws iam delete-access-key <user-name> <access-key-id> # Deletes the access key pair associated with the specified IAM user
(iam-delete-group-cmd {[_ group-name] :match})aws iam delete-group <group-name> # Deletes the specified IAM group. The group must not contain any users or have any attached policies.
aws iam delete-group <group-name> # Deletes the specified IAM group. The group must not contain any users or have any attached policies.
(iam-delete-user-cmd {[_ user-name] :match})aws iam delete-user <user-name> # Deletes the specified IAM user. The user must not belong to any groups or have any access keys, signing certificates, or attached policies.
aws iam delete-user <user-name> # Deletes the specified IAM user. The user must not belong to any groups or have any access keys, signing certificates, or attached policies.
(iam-get-group-cmd {[_ group-name] :match})aws iam get-group <group-name> # Gets IAM user info associated with the <group-name> group
aws iam get-group <group-name> # Gets IAM user info associated with the <group-name> group
(iam-get-user-cmd {[_ user-name] :match})aws iam get-user <user-name> # Retrieves information about the specified IAM user
aws iam get-user <user-name> # Retrieves information about the specified IAM user
(iam-list-access-keys-cmd {[_ user-name] :match})aws iam list-access-keys <user-name> # Returns information about the access key IDs associated with the specified IAM user
aws iam list-access-keys <user-name> # Returns information about the access key IDs associated with the specified IAM user
(iam-list-attached-user-policies-cmd {[_ user-name] :match})aws iam list-attached-user-policies <user-name> # Lists all managed policies that are attached to the specified IAM user.
aws iam list-attached-user-policies <user-name> # Lists all managed policies that are attached to the specified IAM user.
(iam-list-attached-user-policies-in-path-cmd {[_ path user-name] :match})aws iam list-attached-user-policies <path> <user-name> # Lists all managed policies that are attached to the specified IAM user having the specified <path>.
aws iam list-attached-user-policies <path> <user-name> # Lists all managed policies that are attached to the specified IAM user having the specified <path>.
(iam-list-groups-cmd _)aws iam list-groups # Lists the IAM groups in the default / path
aws iam list-groups # Lists the IAM groups in the default / path
(iam-list-groups-in-path-cmd {[_ path] :match})aws iam list-groups <path-prefix> # Lists the IAM groups that have the specified path prefix <path-prefix>
aws iam list-groups <path-prefix> # Lists the IAM groups that have the specified path prefix <path-prefix>
(iam-list-policies-cmd _)aws iam list-policies # Lists all the managed policies that are available in your AWS account
aws iam list-policies # Lists all the managed policies that are available in your AWS account
(iam-list-policies-in-path-cmd {[_ path] :match})aws iam list-policies <path> # Lists all the managed policies that are available in your AWS account within the specified <path>
aws iam list-policies <path> # Lists all the managed policies that are available in your AWS account within the specified <path>
(iam-list-policies-with-scope-in-path-cmd {[_ scope path] :match})aws iam list-policies <scope> <path> # Lists all the managed policies that are available in your AWS account within the specified <path> and <scope>
aws iam list-policies <scope> <path> # Lists all the managed policies that are available in your AWS account within the specified <path> and <scope>
(iam-list-users-cmd _)aws iam list-users # Lists the IAM users within the default / prefix
aws iam list-users # Lists the IAM users within the default / prefix
(iam-list-users-in-path-cmd {[_ path] :match})aws iam list-users <path> # Lists the IAM users that have the specified path prefix
aws iam list-users <path> # Lists the IAM users that have the specified path prefix
(iam-remove-user-from-group-cmd {[_ group-name user-name] :match})aws iam remove-user-from-group <group-name> <user-name> # Removes an aws IAM user <user-name> from the IAM group <group-name>
aws iam remove-user-from-group <group-name> <user-name> # Removes an aws IAM user <user-name> from the IAM group <group-name>
(iam-update-login-profile-cmd {[_ user-name password] :match})aws iam update-login-profile <user-name> <password> # Updates the login profile for the specified user. The password has to be updated by the user at first login.
aws iam update-login-profile <user-name> <password> # Updates the login profile for the specified user. The password has to be updated by the user at first login.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |