(emoji-kitchen {[_ arg1 arg2] :match chat-source :chat-source :as cmd-args})ek <emoji-1> <emoji-2> # fetch an emoji from emoji kitchen
ek <emoji-1> <emoji-2> # fetch an emoji from emoji kitchen
(extract-slack-emoji {:keys [blocks] :as raw-event})Given a slack event, extract the unicode emoji
Given a slack event, extract the unicode emoji
(fetch-emoji emoji-1 emoji-2)Fetch an emoji from emoji kitchen given two unicode emoji
Fetch an emoji from emoji kitchen given two unicode emoji
(hex-to-unichar hex)Convert a hex string to a unicode character
Convert a hex string to a unicode character
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |