(register-not-it {:keys [user]})notit # register a user as not-it
notit # register a user as not-it
(reset-its _)notit reset # resets the current not-it list
notit reset # resets the current not-it list
(show-its _)notit show # show the current list of users registered as not-it
notit show # show the current list of users registered as not-it
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |