(if-prob s f prob)Optionally apply fn f to string s, based on probability prob.
Optionally apply fn f to string s, based on probability prob.
(pirate-cmd {s :match})pirate <string> # translate string into proper pirate, yar
pirate <string> # translate string into proper pirate, yar
(probability)Return probability, by hour, for configured TZ.
Return probability, by hour, for configured TZ.
(suffix-flavor s)Suffix random pirate flavor.
Suffix random pirate flavor.
(wrap-capitalization f)Expects a fn, f, and returns a fn taking one arg: a string. We upper-case the first char of the return of the wrapped fn, f, if the string had an initial upper-case char.
Expects a fn, f, and returns a fn taking one arg: a string. We upper-case the first char of the return of the wrapped fn, f, if the string had an initial upper-case char.
(wrap-punctuation f)Expects a fn, f, and returns a fn taking one arg: a string. We strip trailing punctuation before calling the wrapped fn f, replacing on the return of f.
Expects a fn, f, and returns a fn taking one arg: a string. We strip trailing punctuation before calling the wrapped fn f, replacing on the return of f.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |