(fetch-commands)Returns a list of all the tldr commands available
Returns a list of all the tldr commands available
(tldr command)(tldr platforms command)Returns TLDR page markdown for a command.
Returns TLDR page markdown for a `command`.
(tldr-cmd {[_ command] :match})tldr <command> # get typical usages of a command
tldr <command> # get typical usages of a command
(tldr-platform-cmd {[_ platform command] :match})tldr <platform>/<command> # get typical usages of a command for a platform
tldr <platform>/<command> # get typical usages of a command for a platform
(tldr-random _)Returns a random tldr command
Returns a random tldr command
(tldr-search query)Returns a string of all the tldr commands whose names contain <query>
Returns a string of all the tldr commands whose names contain <query>
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |