(air-cmd {[_ loc] :match})weather air <location> # look up current air conditions for <location> by name or postal code, optional country code
weather air <location> # look up current air conditions for <location> by name or postal code, optional country code
(default-air-cmd _)weather air # look up current weather for default location
weather air # look up current weather for default location
(default-weather-cmd _)weather # look up weather for default location
weather # look up weather for default location
(forecast-cmd {[_ match] :match})weather forecast <location> # look up forecast for <location> by name or postal code, optional country code, -c or -f to force units
weather forecast <location> # look up forecast for <location> by name or postal code, optional country code, -c or -f to force units
(parse-args s)parse args to vec of unit kw and args str
parse args to vec of unit kw and args str
(weather-cmd {:keys [match]})weather <location> # look up current weather for <location> by name or postal code, optional country code, -c or -f to force units
weather <location> # look up current weather for <location> by name or postal code, optional country code, -c or -f to force units
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |