(define {[_ w] :match})wordnik define <word> # look up the definition for <word> on Wordnik
wordnik define <word> # look up the definition for <word> on Wordnik
(random _)wordnik random # look up a random word on Wordnik
wordnik random # look up a random word on Wordnik
(wotd _)wordnik wotd # look up the Word of the Day on Wordnik
wordnik wotd # look up the Word of the Day on Wordnik
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |