(chk-postal-code s)(chk-postal-code s cc)Check postal codes, optionally qualified by CC. Returns a vector of ISO country code and the canonical format of the postal code.
Check postal codes, optionally qualified by CC. Returns a vector of ISO country code and the canonical format of the postal code.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |